Class: Google::Apis::CloudschedulerV1::CloudSchedulerService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudschedulerV1::CloudSchedulerService
- Defined in:
- lib/google/apis/cloudscheduler_v1/service.rb
Overview
Cloud Scheduler API
Creates and manages jobs run on a regular recurring schedule.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudscheduler.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_job(parent, job_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Creates a job.
-
#delete_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Empty
Deletes a job.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Location
Gets information about a location.
-
#get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::CmekConfig
Gets the Scheduler config in the project/region.
-
#get_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Gets a job.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CloudSchedulerService
constructor
A new instance of CloudSchedulerService.
-
#list_project_location_jobs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::ListJobsResponse
Lists jobs.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_job(name, job_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Updates a job.
-
#pause_job(name, pause_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Pauses a job.
-
#resume_job(name, resume_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Resume a job.
-
#run_job(name, run_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Forces a job to run now.
-
#update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Operation
Initializes or Updates the a scheduler config.
Constructor Details
#initialize ⇒ CloudSchedulerService
Returns a new instance of CloudSchedulerService.
47 48 49 50 51 52 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudscheduler_v1', client_version: Google::Apis::CloudschedulerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 533 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::CloudschedulerV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::CloudschedulerV1::Empty::Representation command.response_class = Google::Apis::CloudschedulerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_job(parent, job_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Creates a job.
231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 231 def create_project_location_job(parent, job_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/jobs', ) command.request_representation = Google::Apis::CloudschedulerV1::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::CloudschedulerV1::Job::Representation command.response_class = Google::Apis::CloudschedulerV1::Job command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Empty
Deletes a job.
264 265 266 267 268 269 270 271 272 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 264 def delete_project_location_job(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudschedulerV1::Empty::Representation command.response_class = Google::Apis::CloudschedulerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
568 569 570 571 572 573 574 575 576 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 568 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudschedulerV1::Empty::Representation command.response_class = Google::Apis::CloudschedulerV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudschedulerV1::Location::Representation command.response_class = Google::Apis::CloudschedulerV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::CmekConfig
Gets the Scheduler config in the project/region.
105 106 107 108 109 110 111 112 113 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 105 def get_project_location_cmek_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudschedulerV1::CmekConfig::Representation command.response_class = Google::Apis::CloudschedulerV1::CmekConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Gets a job.
295 296 297 298 299 300 301 302 303 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 295 def get_project_location_job(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudschedulerV1::Job::Representation command.response_class = Google::Apis::CloudschedulerV1::Job command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
599 600 601 602 603 604 605 606 607 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 599 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::CloudschedulerV1::Operation::Representation command.response_class = Google::Apis::CloudschedulerV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_jobs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::ListJobsResponse
Lists jobs.
335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 335 def list_project_location_jobs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/jobs', ) command.response_representation = Google::Apis::CloudschedulerV1::ListJobsResponse::Representation command.response_class = Google::Apis::CloudschedulerV1::ListJobsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 644 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::CloudschedulerV1::ListOperationsResponse::Representation command.response_class = Google::Apis::CloudschedulerV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 157 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::CloudschedulerV1::ListLocationsResponse::Representation command.response_class = Google::Apis::CloudschedulerV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_job(name, job_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Updates a job. If successful, the updated Job is returned. If the job does not
exist, NOT_FOUND is returned. If UpdateJob does not successfully return, it
is possible for the job to be in an Job.State.UPDATE_FAILED state. A job in
this state may not be executed. If this happens, retry the UpdateJob request
until a successful response is received.
384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 384 def patch_project_location_job(name, job_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::CloudschedulerV1::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::CloudschedulerV1::Job::Representation command.response_class = Google::Apis::CloudschedulerV1::Job command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#pause_job(name, pause_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Pauses a job. If a job is paused then the system will stop executing the job until it is re-enabled via ResumeJob. The state of the job is stored in state; if paused it will be set to Job.State.PAUSED. A job must be in Job.State. ENABLED to be paused.
422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 422 def pause_job(name, pause_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:pause', ) command.request_representation = Google::Apis::CloudschedulerV1::PauseJobRequest::Representation command.request_object = pause_job_request_object command.response_representation = Google::Apis::CloudschedulerV1::Job::Representation command.response_class = Google::Apis::CloudschedulerV1::Job command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resume_job(name, resume_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Resume a job. This method reenables a job after it has been Job.State.PAUSED. The state of a job is stored in Job.state; after calling this method it will be set to Job.State.ENABLED. A job must be in Job.State.PAUSED to be resumed.
458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 458 def resume_job(name, resume_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:resume', ) command.request_representation = Google::Apis::CloudschedulerV1::ResumeJobRequest::Representation command.request_object = resume_job_request_object command.response_representation = Google::Apis::CloudschedulerV1::Job::Representation command.response_class = Google::Apis::CloudschedulerV1::Job command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_job(name, run_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Job
Forces a job to run now. When this method is called, Cloud Scheduler will dispatch the job, even if the job is already running.
493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 493 def run_job(name, run_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:run', ) command.request_representation = Google::Apis::CloudschedulerV1::RunJobRequest::Representation command.request_object = run_job_request_object command.response_representation = Google::Apis::CloudschedulerV1::Job::Representation command.response_class = Google::Apis::CloudschedulerV1::Job command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudschedulerV1::Operation
Initializes or Updates the a scheduler config.
196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/google/apis/cloudscheduler_v1/service.rb', line 196 def update_project_location_cmek_config(name, cmek_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::CloudschedulerV1::CmekConfig::Representation command.request_object = cmek_config_object command.response_representation = Google::Apis::CloudschedulerV1::Operation::Representation command.response_class = Google::Apis::CloudschedulerV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |