Class: Google::Apis::CloudschedulerV1::CmekConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudscheduler_v1/classes.rb,
lib/google/apis/cloudscheduler_v1/representations.rb,
lib/google/apis/cloudscheduler_v1/representations.rb

Overview

Describes the project/location configuration of Cloud Scheduler Resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CmekConfig

Returns a new instance of CmekConfig.



212
213
214
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. Resource name of the Cloud KMS key, of the form projects/PROJECT_ID/ locations/LOCATION_ID/keyRings/KEY_RING_ID/cryptoKeys/KEY_ID, that will be used to encrypt Jobs in the region. Setting this as blank will turn off CMEK encryption. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


203
204
205
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 203

def kms_key_name
  @kms_key_name
end

#nameString

Identifier. The config resource name which includes the project and location and must end in 'cmekConfig', in the format projects/PROJECT_ID/locations/ LOCATION_ID/cmekConfig Corresponds to the JSON propertyname`

Returns:

  • (String)


210
211
212
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 210

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



217
218
219
220
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 217

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @name = args[:name] if args.key?(:name)
end