Class: Google::Apis::CloudschedulerV1::OidcToken
- Inherits:
-
Object
- Object
- Google::Apis::CloudschedulerV1::OidcToken
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudscheduler_v1/classes.rb,
lib/google/apis/cloudscheduler_v1/representations.rb,
lib/google/apis/cloudscheduler_v1/representations.rb
Overview
Contains information needed for generating an OpenID Connect token. This type of authorization can be used for many scenarios, including calling Cloud Run, or endpoints where you intend to validate the token yourself.
Instance Attribute Summary collapse
-
#audience ⇒ String
Audience to be used when generating OIDC token.
-
#service_account_email ⇒ String
Service account email to be used for generating OIDC token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OidcToken
constructor
A new instance of OidcToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OidcToken
Returns a new instance of OidcToken.
677 678 679 |
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ String
Audience to be used when generating OIDC token. If not specified, the URI
specified in target will be used.
Corresponds to the JSON property audience
667 668 669 |
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 667 def audience @audience end |
#service_account_email ⇒ String
Service account email to
be used for generating OIDC token. The service account must be within the same
project as the job. The caller must have iam.serviceAccounts.actAs permission
for the service account.
Corresponds to the JSON property serviceAccountEmail
675 676 677 |
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 675 def service_account_email @service_account_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
682 683 684 685 |
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 682 def update!(**args) @audience = args[:audience] if args.key?(:audience) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) end |