Class: Google::Apis::CloudschedulerV1::RetryConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudscheduler_v1/classes.rb,
lib/google/apis/cloudscheduler_v1/representations.rb,
lib/google/apis/cloudscheduler_v1/representations.rb

Overview

Settings that determine the retry behavior. For more information, see Retry jobs. By default, if a job does not complete successfully (meaning that an acknowledgement is not received from the handler, then it will be retried with exponential backoff according to the settings in RetryConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetryConfig

Returns a new instance of RetryConfig.



1000
1001
1002
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 1000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_backoff_durationString

The maximum amount of time to wait before retrying a job after it fails. The default value of this field is 1 hour. Corresponds to the JSON property maxBackoffDuration

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 958

def max_backoff_duration
  @max_backoff_duration
end

#max_doublingsFixnum

The time between retries will double max_doublings times. A job's retry interval starts at min_backoff_duration, then doubles max_doublings times, then increases linearly, and finally retries at intervals of max_backoff_duration up to retry_count times. For examples, see Retry jobs. The default value of this field is 5. Corresponds to the JSON property maxDoublings

Returns:

  • (Fixnum)


968
969
970
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 968

def max_doublings
  @max_doublings
end

#max_retry_durationString

The time limit for retrying a failed job, measured from the time when an execution was first attempted. If specified with retry_count, the job will be retried until both limits are reached. The default value for max_retry_duration is zero, which means retry duration is unlimited. However, if retry_count is also 0, a job attempt won't be retried if it fails. Corresponds to the JSON property maxRetryDuration

Returns:

  • (String)


977
978
979
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 977

def max_retry_duration
  @max_retry_duration
end

#min_backoff_durationString

The minimum amount of time to wait before retrying a job after it fails. The default value of this field is 5 seconds. Corresponds to the JSON property minBackoffDuration

Returns:

  • (String)


983
984
985
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 983

def min_backoff_duration
  @min_backoff_duration
end

#retry_countFixnum

The number of attempts that the system will make to run a job using the exponential backoff procedure described by max_doublings. The default value of retry_count is zero. If retry_count is 0 (and if max_retry_duration is also 0), a job attempt won't be retried if it fails. Instead, Cloud Scheduler system will wait for the next scheduled execution time. Setting retry_count to 0 doesn't prevent failed jobs from running according to schedule after the failure. If retry_count is set to a non-zero number, Cloud Scheduler will retry the failed job, using exponential backoff, for retry_count times until the job succeeds or the number of retries is exhausted. Note that the next scheduled execution time might be skipped if the retries continue through that time. Values greater than 5 and negative values are not allowed. Corresponds to the JSON property retryCount

Returns:

  • (Fixnum)


998
999
1000
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 998

def retry_count
  @retry_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1005
1006
1007
1008
1009
1010
1011
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 1005

def update!(**args)
  @max_backoff_duration = args[:max_backoff_duration] if args.key?(:max_backoff_duration)
  @max_doublings = args[:max_doublings] if args.key?(:max_doublings)
  @max_retry_duration = args[:max_retry_duration] if args.key?(:max_retry_duration)
  @min_backoff_duration = args[:min_backoff_duration] if args.key?(:min_backoff_duration)
  @retry_count = args[:retry_count] if args.key?(:retry_count)
end