Class: Google::Apis::CloudschedulerV1::OAuthToken

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudscheduler_v1/classes.rb,
lib/google/apis/cloudscheduler_v1/representations.rb,
lib/google/apis/cloudscheduler_v1/representations.rb

Overview

Contains information needed for generating an OAuth token. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OAuthToken

Returns a new instance of OAuthToken.



645
646
647
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scopeString

OAuth scope to be used for generating OAuth access token. If not specified, " https://www.googleapis.com/auth/cloud-platform" will be used. Corresponds to the JSON property scope

Returns:

  • (String)


635
636
637
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 635

def scope
  @scope
end

#service_account_emailString

Service account email to be used for generating OAuth token. The service account must be within the same project as the job. The caller must have iam.serviceAccounts.actAs permission for the service account. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


643
644
645
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 643

def 
  @service_account_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



650
651
652
653
# File 'lib/google/apis/cloudscheduler_v1/classes.rb', line 650

def update!(**args)
  @scope = args[:scope] if args.key?(:scope)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
end